summaryrefslogtreecommitdiff
path: root/editor/actions/actions.ml
diff options
context:
space:
mode:
Diffstat (limited to 'editor/actions/actions.ml')
-rwxr-xr-xeditor/actions/actions.ml14
1 files changed, 6 insertions, 8 deletions
diff --git a/editor/actions/actions.ml b/editor/actions/actions.ml
index b150279..f35beef 100755
--- a/editor/actions/actions.ml
+++ b/editor/actions/actions.ml
@@ -3,12 +3,10 @@ open Js_of_ocaml
open Brr
open Brr_note
-module Event = Event
-
type button_actions =
- { delete : Event.t Note.event
- ; redirect : Event.t Note.event
- ; add: Event.t Note.event
+ { delete : State.event Note.event
+ ; redirect : State.event Note.event
+ ; add: State.event Note.event
}
let populate_menu
@@ -87,19 +85,19 @@ let populate_menu
- the list for all the pages presents in the sidebar *)
let redirect_handler =
- (module Load_page.M : Event.Handler with type t = Load_page.M.t ) in
+ (module Load_page.M : State.Event with type t = Load_page.M.t ) in
let redirect_event = Note.E.select
(( Evr.on_el
Ev.click
- (fun _ -> Event.E (None, redirect_handler))
+ (fun _ -> State.E (None, redirect_handler))
home_button
) :: (
List.map2 stored_pages pages
~f:(fun name el ->
Evr.on_el
Ev.click
- (fun _ -> Event.E ((Some name), redirect_handler))
+ (fun _ -> State.E ((Some name), redirect_handler))
el ))) in
let childs =